﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Syncfusion.Pdf;
using Syncfusion.Pdf.Parsing;
using Syncfusion.Pdf.Security;
using Syncfusion.Pdf.Graphics;
using System.IO;
using System.Diagnostics;
using System.Drawing;
using Syncfusion.Pdf.Interactive;

namespace DigitalSignatureSample
{
    class Program
    {
        static void Main(string[] args)
        {
            //Load PDF document 
            PdfLoadedDocument loadedDocument = new PdfLoadedDocument("../../Data/caratula.pdf");

            //Load PDF page
            PdfLoadedPage page = loadedDocument.Pages[0] as PdfLoadedPage;

            //Creates a certificate instance from PFX file with private key
            PdfCertificate pdfCert = new PdfCertificate(@"../../Data/PDF.pfx", "syncfusion");

            //Creates a digital signature
            PdfSignature signature = new PdfSignature(loadedDocument, page, pdfCert, "Signature");

            //Sets signature settings to customize digest algorithm specified
            PdfSignatureSettings settings = signature.Settings;
            settings.CryptographicStandard = CryptographicStandard.CADES; 
            settings.DigestAlgorithm = DigestAlgorithm.SHA256;

            //Sets an image for signature field
            PdfBitmap signatureImage = new PdfBitmap(@"../../Data/logo.png");

            //Sets signature information
            signature.Bounds = new RectangleF(new PointF(0, 0), signatureImage.PhysicalDimension);
            signature.ContactInfo = "johndoe@owned.us";
            signature.LocationInfo = "Honolulu, Hawaii";
            signature.Reason = "I am author of this document.";

            //Draws the signature image
            page.Graphics.DrawImage(signatureImage, 0, 0);

            //Saves and closes the document
            loadedDocument.Save("Output.pdf");
            loadedDocument.Close(true);

            Process.Start("Output.pdf");
        }
    }
}